@@ -10,4 +10,10 @@ class FacebookApiTest(TestCase):
         self.assertEqual(response.id, '4')
         self.assertEqual(response.last_name, 'Zuckerberg')
         self.assertEqual(response.first_name, 'Mark')
-        self.assertEqual(response.gender, 'male')
\ No newline at end of file
+        self.assertEqual(response.gender, 'male')
+
+    def test_empty_result(self):
+
+        result = graph('8576093908/posts', **{'limit': 1000, 'until': 1345661805, 'offset': 0})
+        if result is not None:
+            self.assertEqual(result.error_code, 1)
\ No newline at end of file
